@@ -258,6 +258,7 @@ class SmartDriver(SeleniumDriverCore):
             We retrieve all elements, compute the IOU between the bounding_box and all the elements and pick the best match.
         """
         # Adapt box to local coordinates
+        multiplier = max(1, multiplier) # Make sure multiplier isn't 0.
         new_box = {'x': bounding_box['x'] / multiplier, 'y': bounding_box['y'] / multiplier,
                    'width': bounding_box['width'] / multiplier, 'height': bounding_box['height'] / multiplier}
 
@@ -334,6 +335,7 @@ class ai_elem(webdriver.remote.webelement.WebElement):
                 super(ai_elem, self).__init__(source_elem.parent, source_elem._id)
             self._is_real_elem = True
         self.driver = driver
+        multiplier = max(1, multiplier)
         self.multiplier = multiplier
         self._text = elem.get('text', '')
         self._size = {'width': elem.get('width', 0)/multiplier, 'height': elem.get('height', 0)/multiplier}
