@@ -10,7 +10,6 @@ import time
 import traceback
 import uuid
 import warnings
-
 import io
 from distutils.util import strtobool
 from PIL import Image
@@ -66,7 +65,6 @@ class SeleniumDriverCore(object):
         self.default_prod_url = 'https://smartdriver.dev-tools.ai'
 
         self.scanner = Scanner(self, self.driver, self.url, self.api_key)
-
         test_case_name = initialization_options.get('test_case_name', None)
         if test_case_name is None:
             test_case_name = traceback.format_stack()[0].split()[1].split('/')[-1].split('.py')[0]
@@ -85,19 +83,17 @@ class SeleniumDriverCore(object):
         im = Image.open(io.BytesIO(base64.b64decode(screenshotBase64)))
         width, height = im.size
         self.multiplier = 1.0 * width / window_size['width']
-        self_attrs = dir(self)
         # Disable warnings
         requests.packages.urllib3.disable_warnings()
         warnings.filterwarnings("ignore", category=DeprecationWarning)
 
-        for a_name in dir(driver):
-            if a_name in self_attrs:
+        for a_name in dir(self.driver):
+            if a_name in dir(self):
                 continue
             try:
                 def _call_driver(*args, name=a_name, **kwargs):
                     v = getattr(self.driver, name)
                     return v(*args, **kwargs)
-
                 v = getattr(self.driver, a_name)
                 if hasattr(v, '__call__'):
                     setattr(self, a_name, _call_driver)
@@ -105,6 +101,43 @@ class SeleniumDriverCore(object):
                     setattr(self, a_name, v)
             except Exception as err:
                 continue
+    @property
+    def current_window_handle(self) -> str:
+        return self.driver.current_window_handle
+
+    @property
+    def window_handles(self):
+        return self.driver.window_handles
+    @property
+    def mobile(self):
+        return self.driver._mobile
+    @property
+    def title(self) -> str:
+        return self.driver.title
+    @property
+    def current_url(self) -> str:
+        return self.driver.current_url
+    @property
+    def page_source(self) -> str:
+        return self.driver.page_source
+    @property
+    def switch_to(self):
+        return self.driver.switch_to
+    @property
+    def timeouts(self):
+        return self.driver.timeouts
+    @property
+    def orientation(self):
+        return self.driver.orientation
+    @property
+    def application_cache(self):
+        return self.driver.application_cache
+    @property
+    def log_types(self):
+        return self.driver.log_types
+    @property
+    def virtual_authenticator_id(self) -> str:
+        return self.driver.virtual_authenticator_id
 
     def get(self, url):
         self.driver.get(url)
@@ -135,7 +168,6 @@ class SeleniumDriverCore(object):
                 element = driver.find_element(By.ID, 'foo')
         :rtype: WebElement
         """
-
         # Try to classify with selector
         #    If success, call update_elem ('train_if_necessary': true)
         #    If NOT successful, call _classify
